<?php

/**
 * @file
 * Contains \Drupal\miniorange_saml\Form\MiniorangeSamlCustomerSetup.
 */

namespace Drupal\miniorange_saml_idp\Form;

use Drupal\Core\Form\FormBase;
use Drupal\miniorange_saml_idp\Utilities;
use Drupal\miniorange_saml_idp\MiniorangeSAMLIdpConstants;
use Drupal\miniorange_saml_idp\MiniorangeSAMLCustomer;
use Symfony\Component\HttpFoundation\RedirectResponse;

class MiniorangeSamlCustomerSetup extends FormBase
{

    public function getFormId()
    {
        return 'miniorange_saml_customer_setup';
    }

    public function buildForm(array $form, \Drupal\Core\Form\FormStateInterface $form_state)
    {
        global $base_url;

        $current_status = \Drupal::config('miniorange_saml_idp.settings')->get('miniorange_saml_status');

        if ($current_status == 'VALIDATE_OTP') {

            Utilities::visual_tour_start($form, $form_state);

            $form['markup_top'] = array(
                '#markup' => '<div class="mo_saml_table_layout_1"><div class="mo_saml_table_layout mo_saml_container">'
            );

            $form['miniorange_saml_customer_otp_token'] = array(
                '#type' => 'textfield',
                '#title' => t('OTP<span style="color: red">*</span>'),
                '#attributes' => array('style' => 'width:50%'),
                '#suffix' => '<br/>',
            );

            $form['miniorange_saml_customer_validate_otp_button'] = array(
                '#type' => 'submit',
                '#value' => t('Validate OTP'),
                '#submit' => array('::miniorange_saml_idp_validate_otp_submit'),
            );

            $form['miniorange_saml_customer_setup_resendotp'] = array(
                '#type' => 'submit',
                '#value' => t('Resend OTP'),
                '#submit' => array('::miniorange_saml_idp_resend_otp'),
            );

            $form['miniorange_saml_customer_setup_back'] = array(
                '#type' => 'submit',
                '#value' => t('Back'),
                '#submit' => array('::miniorange_saml_idp_back'),
                '#suffix' => '<br><br><br><br><br><br><br><br>
                        <br><br><br><br><br><br></div>',
            );

            Utilities::spConfigGuide($form, $form_state);
            Utilities::AddSupportButton($form, $form_state);

            return $form;
        } elseif ($current_status == 'PLUGIN_CONFIGURATION') {
            $form['markup_top_message'] = array(
                '#markup' => '<div class="mo_saml_table_layout_1"><div class="mo_saml_table_layout mo_saml_container">
                        <div class="mo_saml_welcome_message">Thank you for registering with miniOrange</div><h4>Your Profile: </h4>'
            );

            $header = array(
                'email' => array(
                    'data' => t('Customer Email')
                ),
                'customerid' => array(
                    'data' => t('Customer ID')
                ),
                'token' => array(
                    'data' => t('Token Key')
                ),
                'apikey' => array(
                    'data' => t('API Key')
                ),
            );

            global $base_url;
            $options = [];

            $options[0] = array(
                'email' => \Drupal::config('miniorange_saml_idp.settings')->get('miniorange_saml_customer_admin_email'),
                'customerid' => \Drupal::config('miniorange_saml_idp.settings')->get('miniorange_saml_customer_id'),
                'token' => \Drupal::config('miniorange_saml_idp.settings')->get('miniorange_saml_customer_admin_token'),
                'apikey' => \Drupal::config('miniorange_saml_idp.settings')->get('miniorange_saml_customer_api_key'),
            );

            $form['fieldset']['customerinfo'] = array(
                '#theme' => 'table',
                '#header' => $header,
                '#rows' => $options,
                '#suffix' => '<br><br><br>',
            );

            $form['miniorange_saml_customer_Remove_Account_info'] = array(
                '#markup' => '<br><br><br><br><br/><h4>Remove Account:</h4><p>This section will help you to remove your current 
                        logged in account without losing your current configurations.</p>'
            );

            $form['miniorange_saml_customer_Remove_Account'] = array(
                '#type' => 'link',
                '#title' => $this->t('Remove Account'),
                '#url' => \Drupal\Core\Url::fromRoute('miniorange_saml_idp.modal_form'),
                '#attributes' => [
                    'class' => [
                        'use-ajax',
                        'button',
                    ],
                ],
                '#suffix' => '<br><br><br><br></div>'
            );

            $form['#attached']['library'][] = 'core/drupal.dialog.ajax';

            Utilities::spConfigGuide($form, $form_state);
            Utilities::AddSupportButton($form, $form_state);

            return $form;
        }

        $url = $base_url . '/admin/config/people/miniorange_saml_idp/customer_setup';

        $tab = isset($_GET['tab']) && $_GET['tab'] == 'login' ? $_GET['tab'] : 'register';

        if ($tab == 'register')
            Utilities::visual_tour_start($form, $form_state);


        $form['markup_top'] = array(
            '#markup' => '<div class="mo_saml_table_layout_1"><div id="Register_Section" class="mo_saml_table_layout mo_saml_container">'
        );

            if ($tab == 'register'){
            $form['markup_msg_1'] = array(
                '#markup' => '<h2>Register with mini<span class="mo_orange"><b>O</b></span>range (Optional)</h2><hr><br/>
                            <div class="mo_saml_highlight_background_note"><h3>Why should I register?</h3>You should register so that in case you need help, we can help you with step by step instructions. 
                    <b>You will also need a miniOrange account to upgrade to the premium version of the module.</b> 
                    We do not store any information except the email that you will use to register with us.</div>
                    '
            );

            $form['mo_register'] = array(
            '#markup' => '<br><div class="mo_saml_highlight_background_note" style="width: auto">If you face any issues during registration then you can <a href="https://www.miniorange.com/businessfreetrial" target="_blank">click here</a> to register and use the same credentials below to login into the module.</div><br>',
          );

            $form['miniorange_saml_customer_register_username'] = array(
                '#type' => 'email',
                '#title' => t('Email<span style="color: red">*</span>'),
                '#description' => t('<b>Note:</b> Use valid EmailId. ( We discourage the use of disposable emails )'),
            );

            $form['miniorange_saml_customer_register_phone'] = array(
                '#type' => 'textfield',
                '#title' => t('Phone'),
                '#description' => t('<b>Note:</b> We will only call if you need support.'),
            );

            $form['miniorange_saml_customer_register_password'] = array(
                '#type' => 'password_confirm',
                '#size' => 6,
            );

            $form['miniorange_saml_customer_register_button'] = array(
                '#type' => 'submit',
                '#value' => t('Register'),
                '#limit_validation_errors' => array(),
                '#prefix' => '<br><div class="ns_row"><div class="ns_name">',
                '#suffix' => '</div>'
            );

            $form['already_account_link'] = array(
                '#markup' => '<a href="'.$url.'/?tab=login" class="mo_idp_btn mo_idp_btn-primary mo_idp_btn-sm"><b>Already have an account?</b></a>',
                '#prefix' => '<div class="ns_value">',
                '#suffix' => '</div></div><br><br>'
            );

        }else{
            $form['markup_15'] = array(
                '#markup' => '<h2>Login with mini<span class="mo_orange"><b>O</b></span>range</h2><hr>',
            );

            $form['markup_16'] = array(
                '#markup' => '<br><div class="mo_saml_highlight_background_note" style="width:35% !important;">Please login with your miniorange account.</b></div><br>'
            );

            $form['miniorange_saml_customer_login_username'] = array(
                '#type' => 'email',
                '#title' => t('Email <span style="color: red">*</span>'),
                '#attributes' => array('style' => 'width:50%'),
            );

            $form['miniorange_saml_customer_login_password'] = array(
                '#type' => 'password',
                '#title' => t('Password <span style="color: red">*</span>'),
                '#attributes' => array('style' => 'width:50%'),
            );

            $form['miniorange_saml_customer_login_button'] = array(
                '#type' => 'submit',
                '#value' => t('Login'),
                '#limit_validation_errors' => array(),
                '#prefix' => '<div class="ns_row"><div class="ns_name">',
                '#suffix' => '</div>'
            );

            $form['register_link'] = array(
                '#markup' => '<a href="'.$url.'" class="mo_idp_btn mo_idp_btn-primary mo_idp_btn-sm"><b>Create an account?</b></a>',
                '#prefix' => '<div class="ns_value">',
                '#suffix' => '</div></div><br>'
            );
        }

        $form['div_for_end'] = array(
            '#markup' => '</div>'
        );

        Utilities::spConfigGuide($form, $form_state);
        Utilities::AddSupportButton($form, $form_state);

        return $form;
    }

    public function submitForm(array &$form, \Drupal\Core\Form\FormStateInterface $form_state)
    {
        global $base_url;

        $tab = isset($_GET['tab']) ? $_GET['tab'] : 'register';
        $phone = '';

        if ($tab == 'register') {
            $username = trim($form['miniorange_saml_customer_register_username']['#value']);
            $phone = trim($form['miniorange_saml_customer_register_phone']['#value']);
            $password = trim($form['miniorange_saml_customer_register_password']['#value']['pass1']);
        }else{
            $username = trim($form['miniorange_saml_customer_login_username']['#value']);
            $password = trim($form['miniorange_saml_customer_login_password']['#value']);
        }
        
        if (empty($username) || empty($password)) {
            \Drupal::messenger()->addMessage(t('The <b><u>Email Address</u></b> and <b><u>Password</u></b> fields are mandatory.'), 'error');
            return;
        }
        
        if ($tab == 'register')
            Utilities::customer_setup_submit($username, $phone, $password);
        else
            Utilities::customer_setup_submit($username, $phone, $password, true);

    }

    public function miniorange_saml_idp_back(&$form, $form_state)
    {   
        Utilities::saml_back();
    }

    public function miniorange_saml_idp_resend_otp(&$form, $form_state)
    {
        Utilities::saml_resend_otp();
    }

    public function miniorange_saml_idp_validate_otp_submit(&$form, $form_state)
    {
        global $base_url;
        $otp_token = trim($form['miniorange_saml_customer_otp_token']['#value']);
        if (empty($otp_token)) {
            \Drupal::messenger()->addMessage(t('OTP field is required.'), 'error');
            return;
        }

        Utilities::validate_otp_submit($otp_token);
        
    }
}
